@@ -6,73 +6,21 @@ import xml.sax.saxutils
 from importlib import resources
 
 from autocoder_nano.actypes import AutoCoderArgs, SingleOutputMeta
-from autocoder_nano.core import AutoLLM, format_str_jinja2, prompt
+from autocoder_nano.core import AutoLLM, prompt
 from autocoder_nano.rag.token_counter import count_tokens
+from autocoder_nano.rules import get_rules_context
 from autocoder_nano.utils.config_utils import prepare_chat_yaml, get_last_yaml_file, convert_yaml_config_to_str
 from autocoder_nano.utils.git_utils import get_uncommitted_changes, commit_changes
 from autocoder_nano.utils.printer_utils import Printer
+from autocoder_nano.agent.agent_define import get_subagent_define
 from autocoder_nano.agent.agentic_edit_types import *
 from autocoder_nano.agent.agentic_edit_tools import *
 from autocoder_nano.utils.sys_utils import detect_env
+from autocoder_nano.utils.color_utils import *
 
 printer = Printer()
 
 
-TOOL_DISPLAY_MESSAGES: Dict[Type[BaseTool], Dict[str, str]] = {
-    ReadFileTool: {
-        "zh": "AutoCoder Nano 想要读取此文件：\n {{ path }}"
-    },
-    WriteToFileTool: {
-        "zh": (
-            "AutoCoder Nano 想要写入此文件：\n{{ path }} \n\n内容片段：\n{{ content_snippet }} {{ ellipsis }} "
-        )
-    },
-    ReplaceInFileTool: {
-        "zh": (
-            "AutoCoder Nano 想要替换此文件中的内容：\n{{ path }} \n\n差异片段：\n{{ diff_snippet }}{{ ellipsis }}"
-        )
-    },
-    ExecuteCommandTool: {
-        "zh": (
-            "AutoCoder Nano 想要执行此命令：\n{{ command }}\n(需要批准：{{ requires_approval }})"
-        )
-    },
-    ListFilesTool: {
-        "zh": (
-            "AutoCoder Nano 想要列出此目录中的文件：\n{{ path }} {{ recursive_text }}"
-        )
-    },
-    SearchFilesTool: {
-        "zh": (
-            "AutoCoder Nano 想要在此目录中搜索文件：\n{{ path }}\n文件模式: {{ file_pattern }}\n正则表达式：{{ regex }}"
-        )
-    },
-    ListCodeDefinitionNamesTool: {
-        "zh": "AutoCoder Nano 想要列出此路径中的定义：\n{{ path }}"
-    },
-    AskFollowupQuestionTool: {
-        "zh": (
-            "AutoCoder Nano 正在提问：\n{{ question }}\n{{ options_text }}"
-        )
-    },
-    RecordMemoryTool: {
-        "zh": (
-            "AutoCoder Nano 正在记录笔记：\n{{ content }}"
-        )
-    },
-    RecallMemoryTool: {
-        "zh": (
-            "AutoCoder Nano 正在检索笔记, 提问：\n{{ query }}"
-        )
-    },
-    WebSearchTool: {
-        "zh": (
-            "AutoCoder Nano 正在联网搜索, 关键词：\n{{ query }}"
-        )
-    }
-}
-
-
 TOOL_RESOLVER_MAP: Dict[Type[BaseTool], Type[BaseToolResolver]] = {
     ExecuteCommandTool: ExecuteCommandToolResolver,
     ReadFileTool: ReadFileToolResolver,
@@ -84,33 +32,10 @@ TOOL_RESOLVER_MAP: Dict[Type[BaseTool], Type[BaseToolResolver]] = {
     AttemptCompletionTool: AttemptCompletionToolResolver,  # Will stop the loop anyway
     TodoReadTool: TodoReadToolResolver,
     TodoWriteTool: TodoWriteToolResolver,
-    WebSearchTool: WebSearchToolResolver
-}
-
-
-AGENT_INIT = {
-    "coding": {
-        "tools": [
-            "execute_command",
-            "read_file",
-            "write_to_file",
-            "replace_in_file",
-            "search_files",
-            "list_files",
-            "ask_followup_question",
-            "attempt_completion",
-            "todo_read",
-            "todo_write"
-        ]
-    },
-    "research": {
-        "tools": [
-            "web_search",
-            "ask_followup_question",
-            "attempt_completion",
-            "write_to_file"
-        ]
-    }
+    WebSearchTool: WebSearchToolResolver,
+    ACModWriteTool: ACModWriteToolResolver,
+    ACModSearchTool: ACModSearchToolResolver,
+    CallSubAgentTool: CallSubAgentToolResolver,
 }
 
 
@@ -123,58 +48,42 @@ class BaseAgent:
         # self.tool_resolver_map = {}  # 子类填充具体工具实现
 
     @staticmethod
-    def get_tool_display_message(tool: BaseTool, lang="zh") -> str:
+    def get_tool_display_message(tool: BaseTool) -> str:
         """ 生成一个用户友好的, 国际化的工具调用字符串表示 """
-        tool_type = type(tool)
-
-        if tool_type not in TOOL_DISPLAY_MESSAGES:  # Fallback for unknown tools
-            return f"Unknown tool type: {tool_type.__name__}\nData: {tool.model_dump_json(indent=2)}"
-
-        templates = TOOL_DISPLAY_MESSAGES[tool_type]
-        template = templates.get(lang, templates.get("en", "Tool display template not found"))  # Fallback to English
-
         if isinstance(tool, ReadFileTool):
-            context = {"path": tool.path}
+            context = f"读取文件：{tool.path}"
         elif isinstance(tool, WriteToFileTool):
-            snippet = tool.content[:150]
-            context = {
-                "path": tool.path, "content_snippet": snippet, "ellipsis": '...' if len(tool.content) > 150 else ''
-            }
+            context = f"写入文件: {tool.path}"
         elif isinstance(tool, ReplaceInFileTool):
-            snippet = tool.diff
-            context = {
-                "path": tool.path, "diff_snippet": snippet, "ellipsis": ''
-            }
+            context = f"变更文件: {tool.path}"
         elif isinstance(tool, ExecuteCommandTool):
-            context = {"command": tool.command, "requires_approval": tool.requires_approval}
+            context = f"执行命令: {tool.command} (是否审批: {tool.requires_approval})"
         elif isinstance(tool, ListFilesTool):
-            context = {"path": tool.path, "recursive_text": '（递归）' if tool.recursive else '（顶层）'}
+            context = f"列出目录: {tool.path} ({'递归' if tool.recursive else '顶层'})"
         elif isinstance(tool, SearchFilesTool):
-            context = {
-                "path": tool.path, "file_pattern": tool.file_pattern or '*', "regex": tool.regex
-            }
-        elif isinstance(tool, ListCodeDefinitionNamesTool):
-            context = {"path": tool.path}
+            context = f"搜索文件: {tool.path}, 文件模式: {tool.file_pattern}, 正则表达式：{tool.regex}"
         elif isinstance(tool, AskFollowupQuestionTool):
             options_text_zh = ""
-            if tool.options:
-                options_list_zh = "\n".join(
+            if tool.options and isinstance(tool.options, list):
+                options_text_zh = "\n".join(
                     [f"- {opt}" for opt in tool.options])  # Assuming options are simple enough not to need translation
-                options_text_zh = f"选项：\n{options_list_zh}"
-            context = {
-                "question": tool.question, "options_text": options_text_zh
-            }
+            context = f"模型提问: {tool.question}, 选项：{options_text_zh}"
+        elif isinstance(tool, WebSearchTool):
+            context = f"联网搜索: {tool.query}"
         elif isinstance(tool, RecordMemoryTool):
-            context = {"content": tool.content}
+            context = f"记录记忆: {tool.content[:50]}"
         elif isinstance(tool, RecallMemoryTool):
-            context = {"query": tool.query}
+            context = f"检索记忆: {tool.query}"
+        elif isinstance(tool, ACModWriteTool):
+            context = f"ACMod 记录: {tool.content[:50]}"
+        elif isinstance(tool, ACModSearchTool):
+            context = f"ACMod 检索: {tool.query}"
+        elif isinstance(tool, CallSubAgentTool):
+            context = f"子代理调用: {tool.agent_type}"
         else:
-            context = tool.model_dump()  # Generic context for tools not specifically handled above
+            context = ""
 
-        try:
-            return format_str_jinja2(template, **context)
-        except Exception as e:
-            return f"Error formatting display for {tool_type.__name__}: {e}\nTemplate: {template}\nContext: {context}"
+        return context
 
     @staticmethod
     def _parse_tool_xml(tool_xml: str, tool_tag: str) -> Optional[BaseTool]:
@@ -184,7 +93,7 @@ class BaseAgent:
             # 在<tool_tag>和</tool_tag>之间查找内容
             inner_xml_match = re.search(rf"<{tool_tag}>(.*?)</{tool_tag}>", tool_xml, re.DOTALL)
             if not inner_xml_match:
-                printer.print_text(f"无法在<{tool_tag}>...</{tool_tag}>标签内找到内容", style="red")
+                printer.print_text(f"无法在<{tool_tag}>...</{tool_tag}>标签内找到内容", style=COLOR_ERROR)
                 return None
             inner_xml = inner_xml_match.group(1).strip()
 
@@ -207,7 +116,7 @@ class BaseAgent:
                         params['options'] = json.loads(params['options'])
                     except json.JSONDecodeError:
                         printer.print_text(f"ask_followup_question_tool 参数JSON解码失败: {params['options']}",
-                                           style="red")
+                                           style=COLOR_ERROR)
                         # 保持为字符串还是处理错误？目前先保持为字符串
                         pass
                 if tool_tag == 'plan_mode_respond' and 'options' in params:
@@ -215,16 +124,16 @@ class BaseAgent:
                         params['options'] = json.loads(params['options'])
                     except json.JSONDecodeError:
                         printer.print_text(f"plan_mode_respond_tool 参数JSON解码失败: {params['options']}",
-                                           style="red")
+                                           style=COLOR_ERROR)
                 # 处理 list_files 工具的递归参数
                 if tool_tag == 'list_files' and 'recursive' in params:
                     params['recursive'] = params['recursive'].lower() == 'true'
                 return tool_cls(**params)
             else:
-                printer.print_text(f"未找到标签对应的工具类: {tool_tag}", style="red")
+                printer.print_text(f"未找到标签对应的工具类: {tool_tag}", style=COLOR_ERROR)
                 return None
         except Exception as e:
-            printer.print_text(f"解析工具XML <{tool_tag}> 失败: {e}\nXML内容:\n{tool_xml}", style="red")
+            printer.print_text(f"解析工具XML <{tool_tag}> 失败: {e}\nXML内容:\n{tool_xml}", style=COLOR_ERROR)
             return None
 
     @staticmethod
@@ -232,7 +141,7 @@ class BaseAgent:
         """ Reconstructs the XML representation of a tool call from its Pydantic model. """
         tool_tag = next((tag for tag, model in TOOL_MODEL_MAP.items() if isinstance(tool, model)), None)
         if not tool_tag:
-            printer.print_text(f"找不到工具类型 {type(tool).__name__} 对应的标签名", style="red")
+            printer.print_text(f"找不到工具类型 {type(tool).__name__} 对应的标签名", style=COLOR_ERROR)
             return f"<error>Could not find tag for tool {type(tool).__name__}</error>"
 
         xml_parts = [f"<{tool_tag}>"]
@@ -458,13 +367,13 @@ class BaseAgent:
                         self.args.source_dir, f"auto_coder_{latest_yaml_file}_{md5}",
                     )
                     if commit_message:
-                        printer.print_text(f"Commit 成功", style="green")
+                        printer.print_text(f"Commit 成功", style=COLOR_SUCCESS)
                 except Exception as err:
                     import traceback
                     traceback.print_exc()
-                    printer.print_text(f"Commit 失败: {err}", style="red")
+                    printer.print_text(f"Commit 失败: {err}", style=COLOR_ERROR)
         else:
-            printer.print_text(f"文件未进行任何更改, 无需 Commit", style="yellow")
+            printer.print_text(f"文件未进行任何更改, 无需 Commit", style=COLOR_WARNING)
 
     @staticmethod
     def _count_conversations_tokens(conversations: list):
@@ -482,7 +391,7 @@ class BaseAgent:
         printer.print_text(f"📝 Token 使用: "
                            f"Input({last_meta.input_tokens_count})/"
                            f"Output({last_meta.generated_tokens_count})",
-                           style="green")
+                           style=COLOR_TOKEN_USAGE)
 
     def _handle_tool_call_event(self, event):
         """处理工具调用事件"""
@@ -491,9 +400,8 @@ class BaseAgent:
             return
 
         tool_name = type(event.tool).__name__
-        # 使用新的国际化显示功能
         display_content = self.get_tool_display_message(event.tool)
-        printer.print_panel(content=display_content, title=f"🛠️ 工具调用: {tool_name}", center=True)
+        printer.print_text(f"️🛠️ 工具调用: {tool_name}, {display_content}", style=COLOR_TOOL_CALL)
 
     def _handle_tool_result_event(self, event):
         """处理工具结果事件"""
@@ -501,23 +409,17 @@ class BaseAgent:
             return
 
         result = event.result
-        title = f"✅ 工具返回: {event.tool_name}" if result.success else f"❌ 工具返回: {event.tool_name}"
-        border_style = "green" if result.success else "red"
-        base_content = f"状态: {'成功' if result.success else '失败'}\n"
-        base_content += f"信息: {result.message}\n"
-
-        # 准备面板内容
-        panel_content = [base_content]
-        content_str = self._format_tool_result_content(result.content)
-
-        # 确定语法高亮器
-        lexer = self._determine_content_lexer(event.tool_name, result.message)
+        if result.success:
+            title = f"✅ 工具返回: {event.tool_name}"
+        else:
+            title = f"❌ 工具返回: {event.tool_name}"
+        base_content = f"状态: {'成功' if result.success else '失败'}, 信息: {result.message}"
 
         # 打印基础信息面板
-        printer.print_panel(
-            content="\n".join(panel_content), title=title, border_style=border_style, center=True)
+        printer.print_text(f"{title}, {base_content}", style=COLOR_TOOL_CALL)
 
-        # 打印语法高亮内容
+        content_str = self._format_tool_result_content(result.content)
+        lexer = self._determine_content_lexer(event.tool_name, result.message)
         if content_str:
             printer.print_code(
                 code=content_str, lexer=lexer, theme="monokai", line_numbers=True, panel=True)
@@ -543,7 +445,7 @@ class BaseAgent:
                 else:
                     content_str = str(result_content)
             except Exception as e:
-                printer.print_text(f"Error formatting tool result content: {e}", style="yellow")
+                printer.print_text(f"Error formatting tool result content: {e}", style=COLOR_WARNING)
                 content_str = _format_content(str(result_content))
 
         return content_str
@@ -551,7 +453,6 @@ class BaseAgent:
     @staticmethod
     def _determine_content_lexer(tool_name, result_message):
         """根据工具类型和内容确定语法高亮器"""
-        lexer = "python"  # Default guess
         if tool_name == "ReadFileTool" and isinstance(result_message, str):
             # Try to guess lexer from file extension in message
             if ".py" in result_message:
@@ -597,19 +498,21 @@ class ToolResolverFactory:
             raise ValueError(f"Resolver class {resolver_class} must be a subclass of BaseToolResolver")
 
         self._resolvers[tool_type] = resolver_class
-        printer.print_text(f"✅ 注册工具解析器: {tool_type.__name__} -> {resolver_class.__name__}", style="green")
+        # printer.print_text(f"✅ 注册工具解析器: {tool_type.__name__} -> {resolver_class.__name__}", style="green")
 
     def register_dynamic_resolver(self, agent_type):
-        if agent_type not in AGENT_INIT:
+        subagent = get_subagent_define()
+        if agent_type not in subagent:
             raise Exception(f"未内置该[{agent_type}] Agent 类型")
 
-        tool_list = AGENT_INIT[agent_type]["tools"]
+        tool_list = subagent[agent_type]["tools"]
 
         for tool in tool_list:
             _tool_type = TOOL_MODEL_MAP[tool]
             _resolver_class = TOOL_RESOLVER_MAP[_tool_type]
 
             self.register_resolver(_tool_type, _resolver_class)
+        printer.print_text(f"已注册 Agent Tool Resolver {len(tool_list)} 个", style=COLOR_DEBUG)
 
     def get_resolvers(self):
         return self._resolvers
@@ -627,10 +530,14 @@ class ToolResolverFactory:
         """获取所有已注册的工具类型"""
         return list(self._resolvers.keys())
 
+    def get_registered_size(self) -> int:
+        """获取所有已注册的工具类型"""
+        return len(self._resolvers.keys())
+
     def clear_instances(self) -> None:
         """清除所有解析器实例"""
         self._resolvers.clear()
-        printer.print_text("🔄 已清除所有工具解析器实例", style="yellow")
+        printer.print_text("🔄 已清除所有工具解析器实例", style=COLOR_WARNING)
 
 
 class PromptManager:
@@ -663,6 +570,11 @@ class PromptManager:
         默认 Shell：{{shell_type}}
         主目录：{{home_dir}}
         当前工作目录：{{current_project}}
+
+        {% if rules_context %}
+        # RULES
+        {{ rules_context }}
+        {% endif %}
         """
         env_info = detect_env()
         shell_type = "bash"
@@ -673,4 +585,5 @@ class PromptManager:
             "home_dir": env_info.home_dir,
             "os_distribution": env_info.os_name,
             "shell_type": shell_type,
+            "rules_context": get_rules_context(self.args.project_root)
         }
\ No newline at end of file
