@@ -8,11 +8,12 @@ from .search_files_tool import SearchFilesToolResolver
 from .list_files_tool import ListFilesToolResolver
 from .ask_followup_question_tool import AskFollowupQuestionToolResolver
 from .attempt_completion_tool import AttemptCompletionToolResolver
-from .record_memory_tool import RecordMemoryToolResolver
-from .recall_memory_tool import RecallMemoryToolResolver
 from .web_search_tool import WebSearchToolResolver
 from .todo_read_tool import TodoReadToolResolver
 from .todo_write_tool import TodoWriteToolResolver
+from .ac_mod_write_tool import ACModWriteToolResolver
+from .ac_mod_search_tool import ACModSearchToolResolver
+from .call_subagent_tool import CallSubAgentToolResolver
 
 __all__ = [
     "BaseToolResolver",
@@ -24,9 +25,10 @@ __all__ = [
     "ListFilesToolResolver",
     "AskFollowupQuestionToolResolver",
     "AttemptCompletionToolResolver",
-    "RecordMemoryToolResolver",
-    "RecallMemoryToolResolver",
     "WebSearchToolResolver",
     "TodoReadToolResolver",
-    "TodoWriteToolResolver"
+    "TodoWriteToolResolver",
+    "ACModWriteToolResolver",
+    "ACModSearchToolResolver",
+    "CallSubAgentToolResolver"
 ]
\ No newline at end of file
