@@ -10,6 +10,7 @@ from autocoder_nano.actypes import SourceCode, VerifyFileRelevance, AutoCoderArg
 from autocoder_nano.core import prompt, extract_code, AutoLLM
 from autocoder_nano.rag.token_counter import count_tokens
 from autocoder_nano.utils.printer_utils import Printer
+from autocoder_nano.utils.color_utils import *
 
 
 printer = Printer()
@@ -86,7 +87,7 @@ class ContentPruner:
                 else:
                     break
             except Exception as e:
-                printer.print_text(f"Failed to read file {file_source.module_name}: {e}", style="red")
+                printer.print_text(f"Failed to read file {file_source.module_name}: {e}", style=COLOR_ERROR)
                 selected_files.append(file_source)
 
         return selected_files
@@ -204,10 +205,10 @@ class ContentPruner:
 
         total_input_tokens = sum(f.tokens for f in file_sources)
         printer.print_text(
-            f"🚀 开始代码片段抽取处理，共 {len(file_sources)} 个文件，总token数: {total_input_tokens}", style="green"
+            f"🚀 开始代码片段抽取处理，共 {len(file_sources)} 个文件，总token数: {total_input_tokens}", style=COLOR_DEBUG
         )
         printer.print_text(
-            f"📋 处理策略: 完整文件优先阈值={full_file_tokens}, 最大token限制={self.max_tokens}", style="green"
+            f"📋 处理策略: 完整文件优先阈值={full_file_tokens}, 最大token限制={self.max_tokens}", style=COLOR_DEBUG
         )
 
         for file_source in file_sources:
@@ -220,7 +221,7 @@ class ContentPruner:
                     token_count += tokens
                     printer.print_text(
                         f"✅ 文件 {file_source.module_name} 完整保留 (token数: {tokens}，当前总token数: {token_count})",
-                        style="green"
+                        style=COLOR_DEBUG
                     )
                     continue
 
@@ -232,13 +233,14 @@ class ContentPruner:
                         self.args.context_prune_sliding_window_overlap
                     )
                     printer.print_text(
-                        f"📊 文件 {file_source.module_name} 通过滑动窗口分割为 {len(chunks)} 个chunks", style="green")
+                        f"📊 文件 {file_source.module_name} 通过滑动窗口分割为 {len(chunks)} 个chunks", style=COLOR_DEBUG)
 
                     all_snippets = []
                     chunk_with_results = 0
                     for chunk_idx, (chunk_start, chunk_end, chunk_content) in enumerate(chunks):
                         printer.print_text(
-                            f"🔍 处理chunk {chunk_idx + 1}/{len(chunks)} (行号: {chunk_start}-{chunk_end})", style="green")
+                            f"🔍 处理chunk {chunk_idx + 1}/{len(chunks)} (行号: {chunk_start}-{chunk_end})",
+                            style=COLOR_DEBUG)
                         extracted = self.extract_code_snippets.with_llm(self.llm).run(
                             conversations=conversations,
                             content=chunk_content,
@@ -251,7 +253,7 @@ class ContentPruner:
                             if snippets:  # 有抽取结果
                                 chunk_with_results += 1
                                 printer.print_text(
-                                    f"✅ chunk {chunk_idx + 1} 抽取到 {len(snippets)} 个代码片段: {snippets}", style="green")
+                                    f"✅ chunk {chunk_idx + 1} 抽取到 {len(snippets)} 个代码片段: {snippets}", style=COLOR_DEBUG)
                                 # 获取到的本来就是在原始文件里的绝对行号
                                 # 后续在构建代码片段内容时，会为了适配数组操作修改行号，这里无需处理
                                 adjusted_snippets = [{
@@ -260,17 +262,18 @@ class ContentPruner:
                                 } for snippet in snippets]
                                 all_snippets.extend(adjusted_snippets)
                             else:
-                                printer.print_text(f"❌ chunk {chunk_idx + 1} 未抽取到相关代码片段", style="red")
+                                printer.print_text(f"❌ chunk {chunk_idx + 1} 未抽取到相关代码片段", style=COLOR_ERROR)
                         else:
-                            printer.print_text(f"❌ chunk {chunk_idx + 1} 抽取失败，未返回结果", style="red")
+                            printer.print_text(f"❌ chunk {chunk_idx + 1} 抽取失败，未返回结果", style=COLOR_ERROR)
                     printer.print_text(
                         f"📈 滑动窗口处理完成: {chunk_with_results}/{len(chunks)} 个chunks有抽取结果，共收集到 {len(all_snippets)} 个代码片段",
-                        style="green"
+                        style=COLOR_DEBUG
                     )
 
                     merged_snippets = self._merge_overlapping_snippets(all_snippets)
 
-                    printer.print_text(f"🔄 合并重叠片段: {len(all_snippets)} -> {len(merged_snippets)} 个片段", style="green")
+                    printer.print_text(f"🔄 合并重叠片段: {len(all_snippets)} -> {len(merged_snippets)} 个片段",
+                                       style=COLOR_DEBUG)
                     # if merged_snippets:
                     #     self.printer.print_str_in_terminal(f"    合并后的片段: {merged_snippets}")
 
@@ -285,18 +288,18 @@ class ContentPruner:
                                 module_name=file_source.module_name, source_code=content_snippets,
                                 tokens=snippet_tokens))
                             token_count += snippet_tokens
-                            printer.print_text(f"✅ 文件 {file_source.module_name} 滑动窗口处理成功，最终抽取到结果", style="green")
+                            printer.print_text(f"✅ 文件 {file_source.module_name} 滑动窗口处理成功，最终抽取到结果", style=COLOR_DEBUG)
                             continue
                         else:
                             printer.print_text(
                                 f"❌ 文件 {file_source.module_name} 滑动窗口处理后token数超限"
                                 f" ({token_count + snippet_tokens} > {self.max_tokens})，停止处理",
-                                style="red"
+                                style=COLOR_ERROR
                             )
                             break
                     else:
                         printer.print_text(
-                            f"⏭️ 文件 {file_source.module_name} 滑动窗口处理后无相关代码片段，跳过处理", style="yellow")
+                            f"⏭️ 文件 {file_source.module_name} 滑动窗口处理后无相关代码片段，跳过处理", style=COLOR_WARNING)
                         continue
 
                 # 抽取关键片段
@@ -307,7 +310,8 @@ class ContentPruner:
                 for index, line in enumerate(lines):
                     new_content += f"{index + 1} {line}\n"
 
-                printer.print_text(f"🔍 开始对文件 {file_source.module_name} 进行整体代码片段抽取 (共 {len(lines)} 行)", style="green")
+                printer.print_text(f"🔍 开始对文件 {file_source.module_name} 进行整体代码片段抽取 (共 {len(lines)} 行)",
+                                   style=COLOR_DEBUG)
 
                 extracted = self.extract_code_snippets.with_llm(self.llm).run(
                     conversations=conversations,
@@ -320,9 +324,9 @@ class ContentPruner:
                     snippets = json.loads(json_str)
 
                     if snippets:
-                        printer.print_text(f"✅ 抽取到 {len(snippets)} 个代码片段: {snippets}", style="green")
+                        printer.print_text(f"✅ 抽取到 {len(snippets)} 个代码片段: {snippets}", style=COLOR_DEBUG)
                     else:
-                        printer.print_text(f"❌ 未抽取到相关代码片段", style="red")
+                        printer.print_text(f"❌ 未抽取到相关代码片段", style=COLOR_ERROR)
 
                     # 只有当有代码片段时才处理
                     if snippets:
@@ -334,21 +338,21 @@ class ContentPruner:
                                                              source_code=content_snippets,
                                                              tokens=snippet_tokens))
                             token_count += snippet_tokens
-                            printer.print_text(f"✅ 文件 {file_source.module_name} 整体抽取成功，最终抽取到结果", style="green")
+                            printer.print_text(f"✅ 文件 {file_source.module_name} 整体抽取成功，最终抽取到结果", style=COLOR_DEBUG)
                         else:
                             printer.print_text(
                                 f"❌ 文件 {file_source.module_name} 整体抽取后token数超限"
                                 f" ({token_count + snippet_tokens} > {self.max_tokens})，停止处理",
-                                style="red")
+                                style=COLOR_ERROR)
                             break
                     else:
                         # 没有相关代码片段，跳过这个文件
-                        printer.print_text(f"⏭️ 文件 {file_source.module_name} 无相关代码片段，跳过处理", style="yellow")
+                        printer.print_text(f"⏭️ 文件 {file_source.module_name} 无相关代码片段，跳过处理", style=COLOR_WARNING)
                 else:
-                    printer.print_text(f"❌ 文件 {file_source.module_name} 整体抽取失败，未返回结果", style="red")
+                    printer.print_text(f"❌ 文件 {file_source.module_name} 整体抽取失败，未返回结果", style=COLOR_ERROR)
 
             except Exception as e:
-                printer.print_text(f"❌ 文件 {file_source.module_name} 处理异常: {e}", style="red")
+                printer.print_text(f"❌ 文件 {file_source.module_name} 处理异常: {e}", style=COLOR_ERROR)
                 continue
 
         total_input_tokens = sum(f.tokens for f in file_sources)
@@ -362,8 +366,8 @@ class ContentPruner:
                 else:
                     snippet_files += 1
 
-        printer.print_text(f"🎯 代码片段抽取处理完成", style="green")
-        printer.print_text(f"📊 处理结果统计:", style="green")
+        printer.print_text(f"🎯 代码片段抽取处理完成", style=COLOR_DEBUG)
+        printer.print_text(f"📊 处理结果统计:", style=COLOR_DEBUG)
         printer.print_key_value(
             items={
                 "输入文件数": f"{len(file_sources)} 个",
@@ -460,7 +464,7 @@ class ContentPruner:
                                           source_code=file_source.source_code, tokens=tokens))
 
             except Exception as e:
-                printer.print_text(f"Failed to count tokens for {file_source.module_name}: {e}", style="red")
+                printer.print_text(f"Failed to count tokens for {file_source.module_name}: {e}", style=COLOR_ERROR)
                 sources.append(SourceCode(module_name=file_source.module_name,
                                           source_code=file_source.source_code, tokens=0))
         return total_tokens, sources
@@ -622,7 +626,7 @@ class ConversationsPruner:
         elif strategy.name == "hybrid":
             return self._hybrid_prune(conversations, strategy.config)
         else:
-            printer.print_text(f"未知策略：{strategy_name}，已默认使用占位策略", style="yellow")
+            printer.print_text(f"未知策略：{strategy_name}，已默认使用占位策略", style=COLOR_WARNING)
             return self._tool_output_cleanup_prune(conversations, strategy.config)
 
     def _hybrid_prune(self, conversations: List[Dict[str, Any]], config: Dict[str, Any]) -> List[Dict[str, Any]]:
@@ -685,12 +689,12 @@ class ConversationsPruner:
         init_tokens = count_tokens(json.dumps(system_conversations + other_conversations, ensure_ascii=False))
         printer.print_text(f"[截断裁剪策略]对话: {len(system_conversations + other_conversations)} 条, "
                            f"Token计数: {init_tokens}",
-                           style="green")
+                           style=COLOR_DEBUG)
         while True:
             current_tokens = count_tokens(json.dumps(system_conversations + other_conversations, ensure_ascii=False))
             if current_tokens <= safe_zone_tokens:
                 printer.print_text(f"Token计数（{current_tokens}）已在安全区（{safe_zone_tokens}）内，停止裁剪",
-                                   style="green")
+                                   style=COLOR_DEBUG)
                 break
 
             # 如果剩余对话不足一组，直接返回系统提示词列表
@@ -701,7 +705,7 @@ class ConversationsPruner:
             other_conversations = other_conversations[group_size:]
 
         final_tokens = count_tokens(json.dumps(system_conversations + other_conversations, ensure_ascii=False))
-        printer.print_text(f"[截断裁剪策略]清理完成, Token计数：{init_tokens} → {final_tokens}", style="green")
+        printer.print_text(f"[截断裁剪策略]清理完成, Token计数：{init_tokens} → {final_tokens}", style=COLOR_DEBUG)
 
         return system_conversations + other_conversations
 
@@ -716,12 +720,12 @@ class ConversationsPruner:
         init_tokens = count_tokens(json.dumps(system_conversations + other_conversations, ensure_ascii=False))
         printer.print_text(f"[摘要裁剪策略]对话: {len(system_conversations + other_conversations)} 条, "
                            f"Token计数: {init_tokens}",
-                           style="green")
+                           style=COLOR_DEBUG)
         while True:
             current_tokens = count_tokens(json.dumps(system_conversations + other_conversations, ensure_ascii=False))
             if current_tokens <= safe_zone_tokens:
                 printer.print_text(f"Token计数（{current_tokens}）已在安全区（{safe_zone_tokens}）内，停止裁剪",
-                                   style="green")
+                                   style=COLOR_DEBUG)
                 break
 
             # 找到要处理的对话组
@@ -743,7 +747,7 @@ class ConversationsPruner:
                                    ] + recent_conversations
 
         final_tokens = count_tokens(json.dumps(system_conversations + other_conversations, ensure_ascii=False))
-        printer.print_text(f"[摘要裁剪策略]清理完成, Token计数：{init_tokens} → {final_tokens}", style="green")
+        printer.print_text(f"[摘要裁剪策略]清理完成, Token计数：{init_tokens} → {final_tokens}", style=COLOR_DEBUG)
         return system_conversations + other_conversations
 
     @prompt()
@@ -774,7 +778,7 @@ class ConversationsPruner:
             if conv.get("role") == "user" and isinstance(conv.get("content"), str) and self._is_tool_result_message(conv.get("content", "")):
                 tool_result_indices.append(i)
 
-        printer.print_text(f"[占位裁剪策略]发现 {len(tool_result_indices)} 条可能需要清理的工具结果消息", style="green")
+        printer.print_text(f"[占位裁剪策略]发现 {len(tool_result_indices)} 条可能需要清理的工具结果消息", style=COLOR_DEBUG)
 
         # 依次清理工具输出，从首个输出开始
         init_tokens = count_tokens(json.dumps(processed_conversations, ensure_ascii=False))
@@ -782,7 +786,7 @@ class ConversationsPruner:
             current_tokens = count_tokens(json.dumps(processed_conversations, ensure_ascii=False))
 
             if current_tokens <= safe_zone_tokens:
-                printer.print_text(f"Token计数（{current_tokens}）已在安全区（{safe_zone_tokens}）内，停止裁剪", style="green")
+                printer.print_text(f"Token计数（{current_tokens}）已在安全区（{safe_zone_tokens}）内，停止裁剪", style=COLOR_DEBUG)
                 break
 
             # 提取工具名称以生成更具体的替换消息
@@ -798,11 +802,11 @@ class ConversationsPruner:
 
                 printer.print_text(
                     f"[占位裁剪策略]已清理索引[{tool_index}]的工具结果({tool_name}),字符数从 {len(original_content)} 减少到 {len(replacement_content)}",
-                    style="green"
+                    style=COLOR_DEBUG
                 )
 
         final_tokens = count_tokens(json.dumps(processed_conversations, ensure_ascii=False))
-        printer.print_text(f"[占位裁剪策略]清理完成。Token计数：{init_tokens} → {final_tokens}", style="green")
+        printer.print_text(f"[占位裁剪策略]清理完成。Token计数：{init_tokens} → {final_tokens}", style=COLOR_DEBUG)
 
         return processed_conversations
 
